.. homely documentation master file, created by
   sphinx-quickstart on Wed Oct  5 20:11:11 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Homely - Dotfile Management
===========================

Contents:

.. toctree::
   :maxdepth: 3

   intro
   installation
   tutorial
   advanced-tutorial

.. toctree::
   :maxdepth: 0
   :name: reftoc
   :caption: Module Reference

   ref/general
   ref/ui
   ref/pipinstall
.. ref/install
   ref/powerline



..  Indices and tables
..  ==================
..
..  * :ref:`genindex`
..  * :ref:`search`
..
